earthkit
========

**earthkit** is a new open-source Python project led by ECMWF, providing powerful tools for speeding up weather
and climate science workflows by simplifying data access, processing, analysis, visualisation and much more.

.. important::

    This software is in **release candidate** stage. It is not yet considered stable and may still undergo significant changes before the final 1.0 release. We welcome feedback and contributions as we approach that milestone.

.. tip::

   For an interactive overview, see the `earthkit website <https://earthkit.ecmwf.int/>`__.


.. grid:: 1
   :gutter: 2

   .. grid-item-card:: Why earthkit?
      :img-top:  _static/earthkit-grey.svg
      :link: why
      :link-type: doc
      :class-card: sd-shadow-sm

      The motivation and key features of earthkit.


.. grid:: 1 1 2 2
   :gutter: 2

   .. grid-item-card:: Installation and Getting Started
      :img-top: _static/rocket.svg
      :link: getting-started
      :link-type: doc
      :class-card: sd-shadow-sm

      New to earthkit? Start here with installation and a quick overview.


   .. grid-item-card:: Tutorials
      :img-top: _static/book.svg
      :link: tutorials/index
      :link-type: doc
      :class-card: sd-shadow-sm

      Step-by-step guides to learn earthkit.

We plan to add many more examples of using Earthkit as a complete package to these pages. In the meantime, we invite you to look at
the documentation for the component Earthkit packages via the navigation drop-down on the left.


**Support**

Have a feature request or found a bug? Feel free to open an
`issue <https://github.com/ecmwf/earthkit/issues/new/choose>`_.



.. toctree::
   :caption: User guide
   :maxdepth: 2
   :hidden:

   getting-started
   tutorials/index



.. toctree::
   :maxdepth: 1
   :caption: Developer guide
   :hidden:

   development/index


.. toctree::
   :maxdepth: 1
   :caption: Installation and Getting Started
   :titlesonly:
   :hidden:

   getting-started


.. toctree::
   :maxdepth: 2
   :caption: Extras
   :hidden:

   licence
